<?php

declare(strict_types=1);

/**
 * @file
 * Contains \Drupal\logout_timeout\Controller\LogoutTimeoutController
 **/

namespace Drupal\logout_timeout\Controller;

use Drupal\logout_timeout\Service\LogoutTimeoutService;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\RequestStack;


/**
 * Returns responses for Logout on Timeout module routes.
 */
class LogoutTimeoutController extends ControllerBase
{

    /**
     * The logout on timeout service.
     *
     * @var \Drupal\logout_timeout\Service\LogoutTimeoutService
     */
    protected $ltService;

    /**
     * LogoutTimeoutController constructor.
     *
     * @param LogoutTimeoutService $ltService
     */
    public function __construct(LogoutTimeoutService $ltService)
    {
        $this->logoutTimeoutService = $ltService;
    }

    /**
     * {@inheritdoc}
     */
    public static function create(ContainerInterface $container)
    {
        return new static(
            $container->get('logout_timeout.service'),
        );
    }

    /**
     * Logout on Timeout logout.
     * 
     * @param int $showMessage
     * 
     * @return RedirectResponse|null
     */
    public function ltLogout(int $showMessage = 1) : ?RedirectResponse
    {

        $redirect_url  = '/' . $this->logoutTimeoutService->getTargetLogoutUrl();
        if ($this->logoutTimeoutService->getSimpleSamlPhpAuthStatus()) {
            $checkSamlAuth = $this->logoutTimeoutService->getCheckSamlAuth();
            if($checkSamlAuth) {
                $simplesaml          = \Drupal::service('simplesamlphp_auth.manager');
                $samlIsActive        = $simplesaml->isActivated();
                $samlIsAuthenticated = $simplesaml->isAuthenticated();

                if ($samlIsActive && $samlIsAuthenticated) {
                    $this->logoutTimeoutService->samlLogout($showMessage, $redirect_url);
                    return null;
                }
            }
        }

        $this->logoutTimeoutService->logout();

        $url = Url::fromUserInput(
            $redirect_url,
            [
                'absolute' => TRUE,
                'query' => [
                    'logout_timeout' => $showMessage,
                ],
            ]
        );

        return new RedirectResponse($url->toString());

    }

}
